sol.views – Pyramid views — SoL 4 developers documentation

# `sol.views` – Pyramid views

class `sol.views.` `LoggerAdapter`(logger, extra)

  Add username and remote IP to the logged message

  `process`(msg, kwargs)

    Process the logging message and keyword arguments passed in to a logging call to insert contextual information. You can either manipulate the message itself, the keyword args or both. Return the message and kwargs modified (or not) to suit your needs.

    Normally, you’ll only need to override this one method in a LoggerAdapter subclass for your specific needs.

`sol.views.` `get_request_logger`(request, logger)

  Get a specialized logger for a Pyramid request

`sol.views.` `json_decode` = <method-wrapper '__call__' of rapidjson.Decoder object>

  Custom JSON decoder.

`sol.views.` `json_encode` = <method-wrapper '__call__' of rapidjson.Encoder object>

  Custom JSON encoder.

`sol.views.` `unauthorized_for_guest`(f)

  Prevent guest users to perform the operation.